reset

set grid
set autoscale x
set autoscale y
set terminal png size 1400,800 enhanced

set xdata time
set timefmt "%Y-%m-%dT%H:%M:%S.UUU"
set format x "%H:%M:%S\n%Y-%m-%d"

graph = sprintf("%s vs %s: EF Position Differences",filetype1,filetype2)
set title graph

set output "pos_diff_vs_utc_time.png"
set multiplot title graph layout 3,1
set xlabel "UTC time"
set grid

set title "Position Coordinate X differences (Earth-Fixed)"
set ylabel "PosX [m]"
set key left top
plot filename using 22:4 notitle with points lt 1

set title "Position Coordinate Y differences (Earth-Fixed)"
set ylabel "PosY [m]"
plot filename using 22:5 notitle with points lt 2

set title "Position Coordinate Z differences (Earth-Fixed)"
set ylabel "PosZ [m]"
plot filename using 22:6 notitle with points lt 3

unset multiplot

set autoscale x
set autoscale y

graph = sprintf("%s vs %s: EF Velocity Differences",filetype1,filetype2)
set title graph

set output "vel_diff_vs_utc_time.png"
set multiplot title graph layout 3,1
set xlabel "UTC Time"
set grid

set title "Velocity Coordinate X differences (Earth-Fixed)"
set ylabel "VelX [m/s]"
set key left top
plot filename using 22:7 notitle with points lt 1

set title "Velocity Coordinate Y differences (Earth-Fixed)"
set ylabel "VelY [m/s]"
plot filename using 22:8 notitle with points lt 2

set title "Velocity Coordinate Z differences (Earth-Fixed)"
set ylabel "VelZ [m/s]"
plot filename using 22:9 notitle with points lt 3

unset multiplot

set autoscale x
set autoscale y

graph = sprintf("%s vs %s: Across-Track/Along-Track/Radial Differences",filetype1,filetype2)
set title graph

set output "across_along_rad_diff_vs_utc_time.png"
set multiplot title graph layout 3,1
set xlabel "UTC Time"
set grid

set title "Across-Track differences"
set ylabel "Across-Track [m]"
set key left top
plot filename using 22:10 notitle with points lt 4

set title "Along-Track differences"
set ylabel "Along-Track[m]"
plot filename using 22:11 notitle with points lt 5

set title "Radial differences"
set ylabel "Radial [m]"
plot filename using 22:12 notitle with points lt 6

unset multiplot

set autoscale x
set autoscale y

graph = sprintf("%s vs %s: Longitude/Latitude/Altitude Differences",filetype1,filetype2)
set title graph

set output "lat_lon_alt_diff_vs_utc_time.png"
set multiplot title graph layout 3,1
set xlabel "UTC Time"
set grid

set title "Longitude differences"
set ylabel "Geocentric Longitude [deg]"
set key left top
plot filename using 22:16 notitle with points lt 7

set title "Latitude differences"
set ylabel "Geodetic Latitude[deg]"
plot filename using 22:17 notitle with points lt 8

set title "Altitude differences"
set ylabel "Geodetic Altitude [m]"
plot filename using 22:18 notitle with points lt 6

unset multiplot

set autoscale x
set autoscale y

graph = sprintf("%s vs %s: MLST/TLST/SZA Differences",filetype1,filetype2)
set title graph

set output "mlst_tlst_sza_diff_vs_utc_time.png"
set multiplot title graph layout 3,1
set xlabel "UTC Time"
set grid

set title "Mean Local Solar Time differences"
set ylabel "MLST [s]"
set key right top
plot filename using 22:($19*3600) notitle with points lt 1

set title "True Local Solar Time differences"
set ylabel "TLST [s]"
plot filename using 22:($20*3600) notitle with points lt 2

set title "Sun Zenith Angle differences"
set ylabel "Sun Zenith Angle [deg]"
plot filename using 22:21 notitle with points lt 3

unset multiplot

set autoscale x
set autoscale y

set ytics

unset xdata
unset timefmt
unset format

reset
