reset

set grid
set autoscale x
set autoscale y
set terminal png size 1400,800 enhanced

set xdata time
set timefmt "%Y-%m-%dT%H:%M:%S.UUU"
set format x "%H:%M:%S\n%Y-%m-%d"

graph = sprintf("%s: EF Position",filetype)
set title graph

set output "pos_vs_utc_time.png"
set multiplot title graph layout 3,1
set xlabel "UTC time"
set grid

set title "Position Coordinate X (Earth-Fixed)"
set ylabel "PosX [m]"
set key right top
plot filename using 7:8 notitle with points lt 1

set title "Position Coordinate Y (Earth-Fixed)"
set ylabel "PosY [m]"
plot filename using 7:9 notitle with points lt 2

set title "Position Coordinate Z (Earth-Fixed)"
set ylabel "PosZ [m]"
plot filename using 7:10 notitle with points lt 3

unset multiplot

set autoscale x
set autoscale y

graph = sprintf("%s: EF Velocity",filetype)
set title graph

set output "vel_vs_utc_time.png"
set multiplot title graph layout 3,1
set xlabel "UTC Time"
set grid

set title "Velocity Coordinate X (Earth-Fixed)"
set ylabel "VelX [m/s]"
set key right top
plot filename using 7:11 notitle with points lt 1

set title "Velocity Coordinate Y (Earth-Fixed)"
set ylabel "VelY [m/s]"
plot filename using 7:12 notitle with points lt 2

set title "Velocity Coordinate Z (Earth-Fixed)"
set ylabel "VelZ [m/s]"
plot filename using 7:13 notitle with points lt 3

unset multiplot

set autoscale x
set autoscale y

graph = sprintf("%s: Osculating Semi-major Axis/Inclination/Eccentricity",filetype)
set title graph

set output "osc_sma_inc_ecc_vs_utc_time.png"
set multiplot title graph layout 3,1
set xlabel "UTC Time"
set grid

set title "Osculating SMA"
set ylabel "Osc. SMA [m]"
set key right top
plot filename using 7:14 notitle with points lt 4

set title "Osculating Inclination"
set ylabel "Osc. Inclination[deg]"
plot filename using 7:15 notitle with points lt 5

set title "Osculating Eccentricity"
set ylabel "Osc. Eccentricity [-]"
plot filename using 7:16 notitle with points lt 6

unset multiplot

set autoscale x
set autoscale y

graph = sprintf("%s: Osculating RAAN/Arg. Perigee/Mean Anomaly",filetype)
set title graph

set output "osc_raan_w_ma_vs_utc_time.png"
set multiplot title graph layout 3,1
set xlabel "UTC Time"
set grid

set title "Osculating RAAN"
set ylabel "Osc. RAAN [deg]"
set key right top
plot filename using 7:17 notitle with points lt 10

set title "Osculating Arg. Perigee"
set ylabel "Osc. Arg. Perigee[deg]"
plot filename using 7:18 notitle with points lt 11

set title "Osculating Mean Anomaly"
set ylabel "Osc. Mean Anomaly[deg]"
plot filename using 7:19 notitle with points lt 9

unset multiplot

set autoscale x
set autoscale y

graph = sprintf("%s: Longitude/Latitude/Altitude",filetype)
set title graph

set output "lat_lon_alt_vs_utc_time.png"
set multiplot title graph layout 3,1
set xlabel "UTC Time"
set grid

set title "Longitude"
set ylabel "Geocentric Longitude [deg]"
set key right top
plot filename using 7:4 notitle with points lt 7

set title "Latitude"
set ylabel "Geodetic Latitude[deg]"
plot filename using 7:5 notitle with points lt 8

set title "Altitude"
set ylabel "Geodetic Altitude [m]"
plot filename using 7:6 notitle with points lt 6

unset multiplot

set autoscale x
set autoscale y


graph = sprintf("%s: MLST/TLST/SZA",filetype)
set title graph

set output "mlst_tlst_sza_vs_utc_time.png"
set multiplot title graph layout 3,1
set xlabel "UTC Time"
set grid

set title "Mean Local Solar Time"
set ylabel "MLST [h]"
set key right top
plot filename using 7:20 notitle with points lt 1

set title "True Local Solar Time"
set ylabel "TLST [h]"
plot filename using 7:21 notitle with points lt 2

set title "Sun Zenith Angle"
set ylabel "Sun Zenith Angle [deg]"
plot filename using 7:22 notitle with points lt 3

unset multiplot

set autoscale x
set autoscale y

set ytics

unset xdata
unset timefmt
unset format


set grid
set autoscale x
set autoscale y
set key default
set terminal png size 1400, 700

set title "SC Latitude vs SC Longitude (Earth map)"
set ylabel "SC Geodetic Latitude (deg)"
set xlabel "SC Geocentric Longitude (deg)"
set output "lon_lat_2DEarth.png"
set yrange [-90.0:90.0]
set xrange [-180.0:180.0]
set xtics -180, 30, 180
set key bottom center
plot "coast_lines2.txt" using 1:2 title "" with points lt 8 ps 0.25, \
filename using (($4<=180.0)?$4:1/0):5 notitle with points  lt 7 pointsize 0.75, \
filename using (($4>180.0)?($4-360.0):1/0):5 notitle with points  lt 7 pointsize 0.75

reset
